==> estateplat-common-1.1.0-20160727.070838-132-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsCq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 过渡历史草权登记
 */
@Table(name = "gd_ls_cq")
public class GdLsCq implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String cqid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 草地共有情况
     */
    private String cdgyqk;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利开始日期
     */
    private Date qlksrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利结束日期
     */
    private Date qljsrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地所有权性质
     */
    private String tdsuqxz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 养殖业方式
     */
    private String yzyfs;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 草原质量
     */
    private String cyzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 适宜载畜量
     */
    private Integer syzcl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 承包面积
     */
    private Double cbmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 备注
     */
    private String bz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 草权证号
     */
    private String cqzh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 单位
     */
    private String  dw;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 数据来源
     */
    private String sjly;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 更新日期
     */
    private Date gxrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 单位代码
     */
    private String dwdm;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 原权证号
     */
    private String yqzh;

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }


    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }


    public String getCqid() {
        return cqid;
    }

    public void setCqid(String cqid) {
        this.cqid = cqid;
    }

    public String getCdgyqk() {
        return cdgyqk;
    }

    public void setCdgyqk(String cdgyqk) {
        this.cdgyqk = cdgyqk;
    }

    public Date getQlksrq() {
        return qlksrq;
    }

    public void setQlksrq(Date qlksrq) {
        this.qlksrq = qlksrq;
    }

    public Date getQljsrq() {
        return qljsrq;
    }

    public void setQljsrq(Date qljsrq) {
        this.qljsrq = qljsrq;
    }

    public String getTdsuqxz() {
        return tdsuqxz;
    }

    public void setTdsuqxz(String tdsuqxz) {
        this.tdsuqxz = tdsuqxz;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }


    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20200723.022823-401-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsCq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 过渡历史草权登记
 */
@Table(name = "gd_ls_cq")
public class GdLsCq implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String cqid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 草地共有情况
     */
    private String cdgyqk;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利开始日期
     */
    private Date qlksrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 权利结束日期
     */
    private Date qljsrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地所有权性质
     */
    private String tdsuqxz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 养殖业方式
     */
    private String yzyfs;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 草原质量
     */
    private String cyzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 适宜载畜量
     */
    private Integer syzcl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 承包面积
     */
    private Double cbmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 备注
     */
    private String bz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 草权证号
     */
    private String cqzh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 面积单位
     */
    private String  mjdw;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 单位代码
     */
    private String dwdm;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登簿人
     */
    private String dbr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登记时间
     */
    private Date djsj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 档案业务号
     */
    private String daywh;

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getCqid() {
        return cqid;
    }

    public void setCqid(String cqid) {
        this.cqid = cqid;
    }

    public String getCdgyqk() {
        return cdgyqk;
    }

    public void setCdgyqk(String cdgyqk) {
        this.cdgyqk = cdgyqk;
    }

    public Date getQlksrq() {
        return qlksrq;
    }

    public void setQlksrq(Date qlksrq) {
        this.qlksrq = qlksrq;
    }

    public Date getQljsrq() {
        return qljsrq;
    }

    public void setQljsrq(Date qljsrq) {
        this.qljsrq = qljsrq;
    }

    public String getTdsuqxz() {
        return tdsuqxz;
    }

    public void setTdsuqxz(String tdsuqxz) {
        this.tdsuqxz = tdsuqxz;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }
}
